### Name: bagg.default
### Title: Predictions from TWIX's or Bagging Trees
### Aliases: bagg bagg.default bagg.bootTWIX bagg.TWIX
### Keywords: tree

### ** Examples

    library(ElemStatLearn)
    data(SAheart)

    ### response variable must be a factor
    SAheart$chd <- factor(SAheart$chd) 

    ### test and train data
    ###
    set.seed(1234)
    icv <- sample(nrow(SAheart),nrow(SAheart)/3)
    itr <- setdiff(1:nrow(SAheart),icv)
    train <- SAheart[itr,]
    test <- SAheart[icv,]

    ### TWIX Ensemble
    M1 <- TWIX(chd~.,data=train,topN=c(4,3),topn.method="single")

    ### Bagging with greedy decision trees as base classifier
    M2 <- bootTWIX(chd~.,data=train,nbagg=30)

    ### Bagging with the p-value adjusted classification trees as base classifier
    M3 <- bootTWIX(chd~.,data=train,nbagg=30,splitf="p-adj",Devmin=0.01)

    preda <- bagg(M1,test,sq=1:length(M1$trees),aggregation="majority")
    predb <- bagg(M1,test,sq=1:length(M1$trees),aggregation="weighted")
    pred1 <- predict(M2,test,sq=1:length(M2$trees))
    pred2 <- predict(M3,test,sq=1:length(M3$trees))

    ###
    ### CCR's
  
    sum(preda == test$chd)/nrow(test)
    sum(predb == test$chd)/nrow(test)
    sum(pred1 == test$chd)/nrow(test)
    sum(pred2 == test$chd)/nrow(test)



